bootstrap

package
v0.1.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseTranscript

func ParseTranscript(path string, maxResponseBytes int) ([]ingest.Event, error)

ParseTranscript reads a Claude Code transcript JSONL file and extracts tool use events into the normalized AgentJIT event schema.

Types

type BootstrapOptions

type BootstrapOptions struct {
	Since   string // YYYY-MM-DD filter
	Project string // Project path filter
	DryRun  bool
}

BootstrapOptions configures the bootstrap run.

type BootstrapResult

type BootstrapResult struct {
	SessionsProcessed int
	EventsImported    int
}

BootstrapResult reports what was bootstrapped.

func RunBootstrap

func RunBootstrap(paths config.Paths, cfg config.Config, claudeProjectsDir string, opts BootstrapOptions) (BootstrapResult, error)

RunBootstrap scans Claude Code transcripts and imports tool use events into AgentJIT's log format. Tracks processed files to avoid re-importing.

type ProcessedFiles

type ProcessedFiles struct {
	Files map[string]time.Time `json:"files"`
}

ProcessedFiles tracks which transcript files have been bootstrapped.

Jump to