Documentation
¶
Index ¶
- func ClaudeProjectsDir() (string, error)
- func ClaudeSettingsGlobal() (string, error)
- func ClaudeSettingsLocal(projectDir string) string
- func ClaudeSkillsGlobal() (string, error)
- func GetField(cfg Config, key string) (interface{}, error)
- func Save(path string, cfg Config) error
- type CompileConfig
- type Config
- type DaemonConfig
- type IngestionConfig
- type Paths
- type ScopeConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ClaudeProjectsDir ¶
ClaudeProjectsDir returns the path to Claude Code's projects directory.
func ClaudeSettingsGlobal ¶
ClaudeSettingsGlobal returns the path to Claude Code's global settings.
func ClaudeSettingsLocal ¶
ClaudeSettingsLocal returns the path to Claude Code's local project settings.
func ClaudeSkillsGlobal ¶
ClaudeSkillsGlobal returns the path to Claude Code's global skills directory.
Types ¶
type CompileConfig ¶
type CompileConfig struct {
TriggerMode string `json:"trigger_mode"`
TriggerIntervalMinutes int `json:"trigger_interval_minutes"`
TriggerEventThreshold int `json:"trigger_event_threshold"`
MaxContextLines int `json:"max_context_lines"`
MinPatternFrequency int `json:"min_pattern_frequency"`
MinTokenSavings int `json:"min_token_savings"`
DeprecateAfterSessions int `json:"deprecate_after_sessions"`
DeterministicThreshold float64 `json:"deterministic_threshold"`
Platform string `json:"platform,omitempty"` // "windows", "linux", "darwin" — auto-detected if empty
}
func (CompileConfig) ResolvePlatform ¶
func (c CompileConfig) ResolvePlatform() string
ResolvePlatform returns the configured platform, or runtime.GOOS if not set.
type Config ¶
type Config struct {
Daemon DaemonConfig `json:"daemon"`
Ingestion IngestionConfig `json:"ingestion"`
Compile CompileConfig `json:"compile"`
Scope ScopeConfig `json:"scope"`
}
func DefaultConfig ¶
func DefaultConfig() Config
type DaemonConfig ¶
type IngestionConfig ¶
type Paths ¶
type Paths struct {
Root string // ~/.aj
Config string // ~/.aj/config.json
Logs string // ~/.aj/logs
Skills string // ~/.aj/skills
PID string // ~/.aj/daemon.pid
Socket string // ~/.aj/daemon.sock
CompileLog string // ~/.aj/compile-log.jsonl
CompileMarker string // ~/.aj/last_compile_marker
BootstrapProcessed string // ~/.aj/bootstrap_processed.json
Stats string // ~/.aj/stats.jsonl
}
Paths holds all filesystem paths used by AJ.
func PathsFromRoot ¶
PathsFromRoot returns Paths rooted at the given directory. Useful for testing with a temp directory.
func (Paths) EnsureDirs ¶
EnsureDirs creates the root, logs, and skills directories if they don't exist.
func (Paths) SessionLogDir ¶
SessionLogDir returns the log directory for a given date string (YYYY-MM-DD).
func (Paths) SessionLogFile ¶
SessionLogFile returns the JSONL file path for a given date and session ID.